/*
 * Copyright © 2003 Maxim Stepin (maxst@hiend3d.com)
 *
 * Copyright © 2010 Cameron Zemek (grom@zeminvaders.net)
 *
 * Copyright © 2011 Tamme Schichler (tamme.schichler@googlemail.com)
 * 
 * Copyright © 2012 A. Eduardo García (arcnorj@gmail.com)
 * 
 * Copyright © 2013 Fabian Praßer (fabian.prasser@gmail.com)
 *
 * This file is part of hqx_dart.
 *
 * hqx_dart is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * hqx_dart is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with hqx_dart. If not, see <http://www.gnu.org/licenses/>.
 */

part of hqx_dart;

class Hqx {
	static int Ymask = 0x00FF0000;
	static int Umask = 0x0000FF00;
	static int Vmask = 0x000000FF;

	/**
	 * Compares two ARGB colors according to the provided Y, U, V and A thresholds.
	 * @param c1 an ARGB color
	 * @param c2 a second ARGB color
	 * @param trY the Y (luminance) threshold
	 * @param trU the U (chrominance) threshold
	 * @param trV the V (chrominance) threshold
	 * @param trA the A (transparency) threshold
	 * @return true if colors differ more than the thresholds permit, false otherwise
	 */
	static bool diff(final int c1, final int c2, final int trY, final int trU, final int trV, final int trA) {
		final int YUV1 = RgbYuv.getYuv(c1);
		final int YUV2 = RgbYuv.getYuv(c2);

		return (
				(((YUV1 & Ymask) - (YUV2 & Ymask)).abs() > trY) ||
				(((YUV1 & Umask) - (YUV2 & Umask)).abs() > trU) ||
				(((YUV1 & Vmask) - (YUV2 & Vmask)).abs() > trV) ||
				((((c1 >> 24) - (c2 >> 24))).abs() > trA)
				);
	}

}
